@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2009-2013 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2009-2015 -- leonerd@leonerd.org.uk
 
 package IO::Async::LoopTests;
 
@@ -27,7 +27,7 @@ use POSIX qw( SIGTERM );
 use Socket qw( sockaddr_family AF_UNIX );
 use Time::HiRes qw( time );
 
-our $VERSION = '0.64';
+our $VERSION = '0.71';
 
 # Abstract Units of Time
 use constant AUT => $ENV{TEST_QUICK_TIMERS} ? 0.1 : 1;
@@ -39,7 +39,7 @@ END { undef $loop }
 
 =head1 NAME
 
-C<IO::Async::LoopTests> - acceptance testing for C<IO::Async::Loop> subclasses
+C<IO::Async::LoopTests> - acceptance testing for L<IO::Async::Loop> subclasses
 
 =head1 SYNOPSIS
 
@@ -51,7 +51,7 @@ C<IO::Async::LoopTests> - acceptance testing for C<IO::Async::Loop> subclasses
 This module contains a collection of test functions for running acceptance
 tests on L<IO::Async::Loop> subclasses. It is provided as a facility for
 authors of such subclasses to ensure that the code conforms to the Loop API
-required by C<IO::Async>.
+required by L<IO::Async>.
 
 =head1 TIMING
 
@@ -72,7 +72,9 @@ system load while testing.
 
 =cut
 
-=head2 run_tests( $class, @tests )
+=head2 run_tests
+
+   run_tests( $class, @tests )
 
 Runs a test or collection of tests against the loop subclass given. The class
 being tested is loaded by this function; the containing script does not need
@@ -158,7 +160,7 @@ Tests the Loop's ability to watch filehandles for IO readiness
 
 =cut
 
-use constant count_tests_io => 17;
+use constant count_tests_io => 18;
 sub run_tests_io
 {
    {
@@ -293,6 +295,11 @@ sub run_tests_io
          $loop->loop_once( 0.1 );
 
          is( $hangup, 1, '$hangup after socket close' );
+
+         $loop->unwatch_io(
+            handle => $S1,
+            on_hangup => 1,
+         );
       }
 
       my ( $Prd, $Pwr ) = IO::Async::OS->pipepair or die "Cannot pipepair - $!";
@@ -309,6 +316,11 @@ sub run_tests_io
       $loop->loop_once( 0.1 );
 
       is( $hangup, 1, '$hangup after pipe close for writing' );
+
+      $loop->unwatch_io(
+         handle => $Pwr,
+         on_hangup => 1,
+      );
    }
 
    # Check that combined read/write handlers can cancel each other
@@ -336,6 +348,28 @@ sub run_tests_io
       is( $callcount, 1, 'read/write_ready can cancel each other' );
    }
 
+   # Check that cross-connected handlers can cancel each other
+   {
+      my ( $SA1, $SA2 ) = IO::Async::OS->socketpair or die "Cannot socketpair - $!";
+      my ( $SB1, $SB2 ) = IO::Async::OS->socketpair or die "Cannot socketpair - $!";
+      $_->blocking( 0 ) for $SA1, $SA2, $SB1, $SB2;
+
+      my @handles = ( $SA1, $SB1 );
+
+      my $callcount = 0;
+      $loop->watch_io(
+         handle => $_,
+         on_write_ready => sub {
+            $callcount++;
+            $loop->unwatch_io( handle => $_, on_write_ready => 1 ) for @handles;
+         },
+      ) for @handles;
+
+      $loop->loop_once( 0.1 );
+
+      is( $callcount, 1, 'write_ready on crosslinked handles can cancel each other' );
+   }
+
    # Check that error conditions that aren't true read/write-ability are still
    # invoked
    {
