@@ -1,20 +1,21 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2007-2012 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2007-2015 -- leonerd@leonerd.org.uk
 
 package IO::Async::Test;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.67';
+our $VERSION = '0.71';
 
 use Exporter 'import';
 our @EXPORT = qw(
    testing_loop
    wait_for
    wait_for_stream
+   wait_for_future
 );
 
 =head1 NAME
@@ -53,23 +54,25 @@ C<IO::Async::Test> - utility functions for use in test scripts
 
  is( substr( $buffer, 0, 10, "" ), "0123456789", 'Buffer was correct' );
 
+ my $result = wait_for_future( $stream->read_until( "\n" ) )->get;
+
 =head1 DESCRIPTION
 
 This module provides utility functions that may be useful when writing test
-scripts for code which uses C<IO::Async> (as well as being used in the
-C<IO::Async> test scripts themselves).
+scripts for code which uses L<IO::Async> (as well as being used in the
+L<IO::Async> test scripts themselves).
 
 Test scripts are often synchronous by nature; they are a linear sequence of
 actions to perform, interspersed with assertions which check for given
-conditions. This goes against the very nature of C<IO::Async> which, being an
+conditions. This goes against the very nature of L<IO::Async> which, being an
 asynchronisation framework, does not provide a linear stepped way of working.
 
 In order to write a test, the C<wait_for> function provides a way of
 synchronising the code, so that a given condition is known to hold, which
-would typically signify that some event has occured, the outcome of which can
+would typically signify that some event has occurred, the outcome of which can
 now be tested using the usual testing primitives.
 
-Because the primary purpose of C<IO::Async> is to provide IO operations on
+Because the primary purpose of L<IO::Async> is to provide IO operations on
 filehandles, a great many tests will likely be based around connected pipes or
 socket handles. The C<wait_for_stream> function provides a convenient way
 to wait for some content to be written through such a connected stream.
@@ -83,9 +86,11 @@ END { undef $loop }
 
 =cut
 
-=head2 testing_loop( $loop )
+=head2 testing_loop
 
-Set the C<IO::Async::Loop> object which the C<wait_for> function will loop
+   testing_loop( $loop )
+
+Set the L<IO::Async::Loop> object which the C<wait_for> function will loop
 on.
 
 =cut
@@ -95,7 +100,9 @@ sub testing_loop
    $loop = shift;
 }
 
-=head2 wait_for( $condfunc )
+=head2 wait_for
+
+   wait_for { COND }
 
 Repeatedly call the C<loop_once> method on the underlying loop (given to the
 C<testing_loop> function), until the given condition function callback
@@ -128,7 +135,9 @@ sub wait_for(&)
    }
 }
 
-=head2 wait_for_stream( $condfunc, $handle, $buffer )
+=head2 wait_for_stream
+
+   wait_for_stream { COND } $handle, $buffer
 
 As C<wait_for>, but will also watch the given IO handle for readability, and
 whenever it is readable will read bytes in from it into the given buffer. The
@@ -176,6 +185,26 @@ sub wait_for_stream(&$$)
    );
 }
 
+=head2 wait_for_future
+
+   $future = wait_for_future $future
+
+I<Since version 0.68.>
+
+A handy wrapper around using C<wait_for> to wait for a L<Future> to become
+ready. The future instance itself is returned, allowing neater code.
+
+=cut
+
+sub wait_for_future
+{
+   my ( $future ) = @_;
+
+   wait_for { $future->is_ready };
+
+   return $future;
+}
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
