@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2009-2012 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2009-2015 -- leonerd@leonerd.org.uk
 
 package IO::Async::Timer::Periodic;
 
@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( IO::Async::Timer );
 
-our $VERSION = '0.61';
+our $VERSION = '0.71';
 
 use Carp;
 
@@ -69,18 +69,16 @@ Invoked on each interval of the timer.
 
 The following named parameters may be passed to C<new> or C<configure>:
 
-=over 8
-
-=item on_tick => CODE
+=head2 on_tick => CODE
 
 CODE reference for the C<on_tick> event.
 
-=item interval => NUM
+=head2 interval => NUM
 
 The interval in seconds between invocations of the callback or method. Cannot
 be changed if the timer is running.
 
-=item first_interval => NUM
+=head2 first_interval => NUM
 
 Optional. If defined, the interval in seconds after calling the C<start>
 method before the first invocation of the callback or method. Thereafter, the
@@ -91,7 +89,7 @@ Even if this value is zero, the first invocation will be made asynchronously,
 by the containing C<Loop> object, and not synchronously by the C<start> method
 itself.
 
-=item reschedule => STRING
+=head2 reschedule => STRING
 
 Optional. Must be one of C<hard>, C<skip> or C<drift>. Defines the algorithm
 used to reschedule the next invocation.
@@ -109,8 +107,6 @@ previous iteration's event handler returns. This allows it to slowly drift over
 time and become desynchronised with other events of the same interval or
 multiples/fractions of it.
 
-=back
-
 Once constructed, the timer object will need to be added to the C<Loop> before
 it will work. It will also need to be started by the C<start> method.
 
@@ -170,42 +166,51 @@ sub configure
    $self->SUPER::configure( %params );
 }
 
-sub _next_interval
+sub _reschedule
 {
    my $self = shift;
-   return $self->{first_interval} if defined $self->{first_interval};
-   return $self->{interval};
+
+   my $now = $self->loop->time;
+   my $resched = $self->{reschedule};
+
+   my $next_interval = $self->{is_first} && defined $self->{first_interval}
+      ? $self->{first_interval} : $self->{interval};
+   delete $self->{is_first};
+
+   if( !defined $self->{next_time} ) {
+      $self->{next_time} = $now + $next_interval;
+   }
+   elsif( $resched eq "hard" ) {
+      $self->{next_time} += $next_interval;
+   }
+   elsif( $resched eq "skip" ) {
+      # How many ticks are needed?
+      my $ticks = POSIX::ceil( $now - $self->{next_time} );
+      # $self->{last_ticks} = $ticks;
+      $self->{next_time} += $next_interval * $ticks;
+   }
+   elsif( $resched eq "drift" ) {
+      $self->{next_time} = $now + $next_interval;
+   }
+
+   $self->SUPER::start;
 }
 
 sub start
 {
    my $self = shift;
 
+   $self->{is_first} = 1;
+
    # Only actually define a time if we've got a loop; otherwise it'll just
    # become start-pending. We'll calculate it properly when it gets added to
    # the Loop
-   if( my $loop = $self->loop ) {
-      my $now = $loop->time;
-      my $resched = $self->{reschedule};
-
-      if( !defined $self->{next_time} ) {
-         $self->{next_time} = $now + $self->_next_interval;
-      }
-      elsif( $resched eq "hard" ) {
-         $self->{next_time} += $self->_next_interval;
-      }
-      elsif( $resched eq "skip" ) {
-         # How many ticks are needed?
-         my $ticks = POSIX::ceil( $now - $self->{next_time} );
-         # $self->{last_ticks} = $ticks;
-         $self->{next_time} += $self->_next_interval * $ticks;
-      }
-      elsif( $resched eq "drift" ) {
-         $self->{next_time} = $now + $self->_next_interval;
-      }
+   if( $self->loop ) {
+      $self->_reschedule;
+   }
+   else {
+      $self->SUPER::start;
    }
-
-   $self->SUPER::start;
 }
 
 sub stop
@@ -223,14 +228,15 @@ sub _make_cb
    return $self->_capture_weakself( sub {
       my $self = shift or return;
 
-      undef $self->{first_interval};
-
       undef $self->{id};
 
-      $self->invoke_event( on_tick => );
+      my $ok = eval { $self->invoke_event( on_tick => ); 1 } or
+         my $e = $@;
 
       # detect ->stop
-      $self->start if defined $self->{next_time};
+      $self->_reschedule if defined $self->{next_time};
+
+      die $e if !$ok;
    } );
 }
 
